package PDL::Role::RowNameable;

use strict;
use warnings;

# TODO

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

PDL::Role::RowNameable

=head1 VERSION

version 0.0045

=head1 AUTHORS

=over 4

=item *

Zakariyya Mughal <zmughal@cpan.org>

=item *

Stephan Loyd <sloyd@cpan.org>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014, 2019 by Zakariyya Mughal, Stephan Loyd.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
